DeviceScreenBrightnessBindings class
Bindings for device_screen_brightness native library.
Constructors
- DeviceScreenBrightnessBindings(DynamicLibrary dynamicLibrary)
-
The symbols are looked up in
dynamicLibrary. -
DeviceScreenBrightnessBindings.fromLookup(Pointer<
T> lookup<T extends NativeType>(String symbolName) ) -
The symbols are looked up with
lookup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
device_screen_brightness_decrement(
) → DeviceScreenBrightnessResult -
device_screen_brightness_get(
) → DeviceScreenBrightnessResult -
device_screen_brightness_increment(
) → DeviceScreenBrightnessResult -
device_screen_brightness_set(
int value) → DeviceScreenBrightnessResult -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited